@@ -10,7 +10,6 @@ from typing import TYPE_CHECKING
 import aiohttp
 import asyncstdlib
 import ujson
-from discord.backoff import ExponentialBackoff
 
 from pylav._logging import getLogger
 from pylav.constants import (
@@ -25,7 +24,7 @@ from pylav.location import get_closest_region_name_and_coordinate
 from pylav.node import Node
 from pylav.player import Player
 from pylav.sql.models import LibConfigModel, NodeModelMock
-from pylav.utils import sort_key_nodes
+from pylav.utils import ExponentialBackoffWithReset, sort_key_nodes
 
 if TYPE_CHECKING:
     from pylav.client import Client
@@ -34,6 +33,18 @@ LOGGER = getLogger("PyLav.NodeManager")
 
 
 class NodeManager:
+    __slots__ = (
+        "_client",
+        "_session",
+        "_player_queue",
+        "_unmanaged_external_host",
+        "_unmanaged_external_password",
+        "_unmanaged_external_port",
+        "_unmanaged_external_ssl",
+        "_nodes",
+        "_adding_nodes",
+    )
+
     def __init__(
         self,
         client: Client,
@@ -287,7 +298,7 @@ class NodeManager:
         coordinates: tuple[float, float] = None,
         wait: bool = False,
         attempt: int = 0,
-        backoff: ExponentialBackoff = None,
+        backoff: ExponentialBackoffWithReset = None,
     ) -> Node | None:
         """Finds the best (least used) node in the given region, if applicable.
         Parameters
@@ -306,14 +317,14 @@ class NodeManager:
             Whether to wait for a node to become available.
         attempt: :class:`int`
             The current attempt number.
-        backoff: :class:`ExponentialBackoff`
+        backoff: :class:`ExponentialBackoffWithReset`
             The backoff to use.
         Returns
         -------
         Optional[:class:`Node`]
         """
         if backoff is None:
-            backoff = ExponentialBackoff()
+            backoff = ExponentialBackoffWithReset()
             delay = 1
         else:
             delay = backoff.delay()
@@ -454,6 +465,9 @@ class NodeManager:
     async def connect_to_all_nodes(self) -> None:
         nodes_list = []
         async for node in asyncstdlib.iter(await self.client.node_db_manager.get_all_unamanaged_nodes()):
+            if node.id == self.client.bot.user.id:
+                LOGGER.debug("Skipping node %s as it is the managed node", node.id)
+                continue
             node_data = await node.fetch_all()
             try:
                 if node in nodes_list:
